@@ -84,8 +84,10 @@ void Stats::report(FILE *output)
 #endif
   for (auto& i : flag_ignore_files)
     fprintf(output, "  --ignore-files='%s'" NEWLINESTR, i.c_str());
+  if (flag_sort != NULL)
+    fprintf(output, "  --sort=%s" NEWLINESTR, flag_sort);
   for (auto& i : ignore)
-    fprintf(output, "    %s exclusions were applied to %s" NEWLINESTR, i.c_str(), i.substr(0, i.find_last_of(PATHSEPCHR)).c_str());
+    fprintf(output, "    %s exclusions were applied to %s and its subdirectories" NEWLINESTR, i.c_str(), i.substr(0, i.find_last_of(PATHSEPCHR)).c_str());
   for (auto& i : flag_file_magic)
   {
     if (!i.empty() && (i.front() == '!' || i.front() == '^'))
